@@ -1,5 +1,5 @@
 package Language::LispPerl::BuiltIns;
-$Language::LispPerl::BuiltIns::VERSION = '0.004';
+$Language::LispPerl::BuiltIns::VERSION = '0.005';
 use Moose;
 
 use Carp;
@@ -479,8 +479,8 @@ sub _impl_fn{
     }
 
     my $nast = Language::LispPerl::Atom->new({ type => "function", value => $ast });
-
-    $nast->{context} = $self->evaler()->copy_current_scope();
+    my $current_scope = $self->evaler()->copy_current_scope();
+    $nast->context( $current_scope );
 
     return $nast;
 }
